@@ -13,6 +13,10 @@ def init_qt_support():
         from default.gdb_qt import cidrDumper, qtMatcher
 
         cidrDumper.loadDumpers({})
+        # int8_t and uint8_t dumpers change the -data-list-register-values output
+        # which affects vector registers presentation. Disable them:
+        del cidrDumper.qqDumpers['int8_t']
+        del cidrDumper.qqDumpers['uint8_t']
 
         args = {
             'fancy': 1,
